@@ -12,20 +12,13 @@ http://dev.appneta.com/docs/api-v2/latency.html
 from .resource import Resource
 
 
-class Server(object):
+class Server(Resource):
     """ The :class:`Server <Server>` class.
 
     Get server side latency information.
 
-    :param api_key: The TraceView API access key.
-
     """
 
-    def __init__(self, *args, **kwargs):
-        self._series = Series("server", *args, **kwargs)
-        self._summary = Summary("server", *args, **kwargs)
-        self._by_layer = ByLayer("server", *args, **kwargs)
-
     def latency_series(self, app, *args, **kwargs):
         """ Get a timeseries line of the applications latency and volume.
 
@@ -50,7 +43,8 @@ class Server(object):
           {u'fields': u'timestamp,volume,avg_latency', u'items': [[1399089120.0, 27.0, 226074.07407407407], ...]}
 
         """
-        return self._series.get(app, *args, **kwargs)
+        path = 'latency/{app}/server/series'.format(app=app)
+        return self.api.get(path, *args, **kwargs)
 
     def latency_summary(self, app, *args, **kwargs):
         """ Get a summary of the latency and volume traced.
@@ -74,7 +68,8 @@ class Server(object):
           {u'count': 2402.0, u'average': 271437.13572023314, u'latest': 19530.61224489796}
 
         """
-        return self._summary.get(app, *args, **kwargs)
+        path = 'latency/{app}/server/summary'.format(app=app)
+        return self.api.get(path, *args, **kwargs)
 
     def latency_by_layer(self, app, *args, **kwargs):
         """ Get timeseries data grouped by application layers.
@@ -104,23 +99,17 @@ class Server(object):
           ]
 
         """
-        return self._by_layer.get(app, *args, **kwargs)
+        path = 'latency/{app}/server/by-layer'.format(app=app)
+        return self.api.get(path, *args, **kwargs)
 
 
-class Client(object):
+class Client(Resource):
     """ The :class:`Client <Client>` class.
 
     Get client side latency information.
 
-    :param api_key: The TraceView API access key.
-
     """
 
-
-    def __init__(self, *args, **kwargs):
-        self._series = Series("client", *args, **kwargs)
-        self._summary = Summary("client", *args, **kwargs)
-
     def latency_series(self, app, *args, **kwargs):
         """ Get a timeseries line of the applications latency and volume.
 
@@ -147,7 +136,8 @@ class Client(object):
           {u'fields': u'timestamp,volume,avg_latency', u'items': [[1399090230.0, 0, None], ...]}
 
         """
-        return self._series.get(app, *args, **kwargs)
+        path = 'latency/{app}/client/series'.format(app=app)
+        return self.api.get(path, *args, **kwargs)
 
     def latency_summary(self, app, *args, **kwargs):
         """ Get a summary of the latency and volume traced.
@@ -174,83 +164,5 @@ class Client(object):
 
 
         """
-        return self._summary.get(app, *args, **kwargs)
-
-
-class Series(Resource):
-
-    PATH = "latency/{app}/{data_type}/series"
-
-    def __init__(self, data_type, *args, **kwargs):
-        """ Construct a :class:`Series <Series>` object.
-
-        :param data_type: The type of latency data, can be "server" or "client".
-
-        """
-        super(Series, self).__init__(*args, **kwargs)
-        self.data_type = data_type
-
-    def get(self, app, *args, **kwargs):
-        """ Call the :class:`Series <Series>` object.
-
-        Return a Dictionary that contains timeseries data of the applications
-        latency and volume, either from a client-side or server-side
-        perspective. Each point is a triple of (timestamp, volume, latency)
-
-        :param app: The app name.
-
-        """
-        self.path = self.PATH.format(app=app, data_type=self.data_type)
-        return super(Series, self).get(*args, **kwargs)
-
-
-class Summary(Resource):
-
-    PATH = "latency/{app}/{data_type}/summary"
-
-    def __init__(self, data_type, *args, **kwargs):
-        """ Construct a :class:`Summary <Summary>` object.
-
-        :param data_type: The type of latency data, can be "server" or "client".
-
-        """
-        super(Summary, self).__init__(*args, **kwargs)
-        self.data_type = data_type
-
-    def get(self, app, *args, **kwargs):
-        """ Call the :class:`Summary <Summary>` object.
-
-        Returns a Dictionary containing the summary of the latency and volume
-        traced, for either the client side or the server side.
-
-        :param app: The app name.
-
-        """
-        self.path = self.PATH.format(app=app, data_type=self.data_type)
-        return super(Summary, self).get(*args, **kwargs)
-
-
-class ByLayer(Resource):
-
-    PATH = "latency/{app}/{data_type}/by-layer"
-
-    def __init__(self, data_type, *args, **kwargs):
-        """ Construct a :class:`ByLayer <ByLayer>` object.
-
-        :param data_type: The type of latency data, can be "server" or "client".
-
-        """
-        super(ByLayer, self).__init__(*args, **kwargs)
-        self.data_type = data_type
-
-    def get(self, app, *args, **kwargs):
-        """ Call the :class:`ByLayer <ByLayer>` object.
-
-        Returns a Dictionary containing the summary of the latency and volume
-        traced, for either the client side or the server side.
-
-        :param app: The app name.
-
-        """
-        self.path = self.PATH.format(app=app, data_type=self.data_type)
-        return super(ByLayer, self).get(*args, **kwargs)
+        path = 'latency/{app}/client/summary'.format(app=app)
+        return self.api.get(path, *args, **kwargs)
